PyDocSearch
===========

A simple Python module to search in Python Documentation.

.. code:: pycon

    >>> import pydocsearch
    >>> pydocsearch.search('lambda')
    'https://docs.python.org/3.5/glossary.html#term-lambda'
